@@ -569,6 +569,42 @@ class Flwdir(object):
             )
         return accu.reshape(data.shape)
 
+    def smooth_rivlen(
+        self,
+        rivlen,
+        min_rivlen,
+        max_window=10,
+        nodata=-9999.0,
+    ):
+        """Return smoothed river length, by taking the window average of river length.
+        The window size is increased until the average exceeds the `min_rivlen` threshold
+        or the `max_window` size is reached.
+
+        Parameters
+        ----------
+        rivlen : 2D array of float
+            River length values.
+        min_rivlen : float
+            Minimum river length.
+        max_window : int
+            maximum window size
+
+        Returns
+        -------
+        2D array of float
+            River length values.
+        """
+        rivlen_out = streams.smooth_rivlen(
+            idxs_ds=self.idxs_ds,
+            idxs_us_main=self.idxs_us_main,
+            rivlen=self._check_data(rivlen, "rivlen"),
+            min_rivlen=min_rivlen,
+            max_window=max_window,
+            nodata=nodata,
+            mv=self._mv,
+        )
+        return rivlen_out.reshape(rivlen.shape)
+
     ### ELEVATION ###
 
     def dem_adjust(self, elevtn):
@@ -685,7 +721,8 @@ class Flwdir(object):
         if rivslp is None:
             dz = zs - self.downstream(zs)
             dx = rivdst - self.downstream(rivdst)
-            rivslp = np.where(dx > 0, dz / dx, min_rivslp)
+            rivslp = np.where(dx >= 1, dz / np.maximum(1, dx), -9999)
+            rivslp = self.fillnodata(rivslp, nodata=-9999)
         rivslp = np.maximum(min_rivslp, rivslp)
         # get (initial) river depth based on manning's equation
         rivdph = ((manning * qbankfull) / (np.sqrt(rivslp) * rivwth)) ** (3 / 5)
@@ -711,7 +748,7 @@ class Flwdir(object):
     ### SHORTCUTS ###
 
     def _check_data(self, data, name, optional=False, flatten=True, **kwargs):
-        """check or calculate upstream area cells; return flattened array"""
+        """check data shape and size; by default return flattened array"""
         if data is None and optional:
             return
         if data is None:
